@@ -6,13 +6,13 @@
     :date: 2021/09/02 22:20:52
 '''
 
-from school_api.client.api.schedules import Schedule
-from school_api.client.api import login
-from school_api.client.exceptions import LoginException
+from school_sdk.client.api.schedules import Schedule
+from school_sdk.client.api import login
+from school_sdk.client.exceptions import LoginException
 import time
-from school_api.client.api.login import ZFLogin
-from school_api.client.base import BaseSchoolClient
-from school_api.utils import ObjectDict
+from school_sdk.client.api.login import ZFLogin
+from school_sdk.client.base import BaseSchoolClient
+from school_sdk.utils import ObjectDict
 
 
 class SchoolClient():
