@@ -7,9 +7,9 @@
 '''
 
 
-from school_api.client.api.schedule_parse import ScheduleParse
-from school_api.client.api import BaseCrawler
-from school_api.client.settings import PERSON_SCHEDULE_API
+from school_sdk.client.api.schedule_parse import ScheduleParse
+from school_sdk.client.api import BaseCrawler
+from school_sdk.client.settings import PERSON_SCHEDULE_API
 
 
 class Schedule(BaseCrawler):
